aboutsummaryrefslogtreecommitdiffstats
path: root/gwtquery-core
diff options
context:
space:
mode:
authorManolo Carrasco <manolo@apache.org>2011-07-28 09:45:03 +0000
committerManolo Carrasco <manolo@apache.org>2011-07-28 09:45:03 +0000
commit1ab8c0614fc387bb25af3868624d5da8727bdc84 (patch)
tree75ccf754724e5dc91a053500e47af688025f0135 /gwtquery-core
parent9db75b2103c3e2258f0c8a5c9fc6e426ba3fc1a6 (diff)
downloadgwtquery-1ab8c0614fc387bb25af3868624d5da8727bdc84.tar.gz
gwtquery-1ab8c0614fc387bb25af3868624d5da8727bdc84.zip
update lazy interfaces, deprecated visible() method in favor of isVisible()
Diffstat (limited to 'gwtquery-core')
-rw-r--r--gwtquery-core/src/main/java/com/google/gwt/query/client/LazyGQuery.java8
-rw-r--r--gwtquery-core/src/main/java/com/google/gwt/query/client/plugins/LazyEffects.java1
2 files changed, 4 insertions, 5 deletions
diff --git a/gwtquery-core/src/main/java/com/google/gwt/query/client/plugins/LazyEffects.java b/gwtquery-core/src/main/java/com/google/gwt/query/client/plugins/LazyEffects.java
index fd387cb6..0f94e76a 100644
--- a/gwtquery-core/src/main/java/com/google/gwt/query/client/plugins/LazyEffects.java
+++ b/gwtquery-core/src/main/java/com/google/gwt/query/client/plugins/LazyEffects.java
@@ -20,6 +20,7 @@ import com.google.gwt.query.client.Function;
import com.google.gwt.query.client.GQuery;
import com.google.gwt.query.client.Properties;
import com.google.gwt.query.client.plugins.effects.ClipAnimation;
+import com.google.gwt.query.client.plugins.effects.Fx;
import com.google.gwt.query.client.plugins.effects.PropertiesAnimation;
import com.google.gwt.query.client.plugins.effects.ClipAnimation.Action;
import com.google.gwt.query.client.plugins.effects.ClipAnimation.Direction;
diff --git a/gwtquery-core/src/main/java/com/google/gwt/query/client/LazyGQuery.java b/gwtquery-core/src/main/java/com/google/gwt/query/client/LazyGQuery.java
index 2abdcde2..bc82e246 100644
--- a/gwtquery-core/src/main/java/com/google/gwt/query/client/LazyGQuery.java
+++ b/gwtquery-core/src/main/java/com/google/gwt/query/client/LazyGQuery.java
@@ -38,9 +38,7 @@ import com.google.gwt.query.client.css.HasCssValue;
import com.google.gwt.query.client.css.TakesCssValue;
import com.google.gwt.query.client.css.TakesCssValue.CssSetter;
import com.google.gwt.query.client.impl.DocumentStyleImpl;
-import com.google.gwt.query.client.impl.HasSelector;
import com.google.gwt.query.client.impl.SelectorEngine;
-import com.google.gwt.query.client.impl.SelectorEngineCssToXPath;
import com.google.gwt.query.client.js.JsCache;
import com.google.gwt.query.client.js.JsMap;
import com.google.gwt.query.client.js.JsNamedArray;
@@ -2121,7 +2119,7 @@ public interface LazyGQuery<T> extends LazyBase<T>{
* Remove all duplicate elements from an array of elements. Note that this
* only works on arrays of DOM elements, not strings or numbers.
*/
- JsNodeArray unique(JsNodeArray result);
+ JsNodeArray unique(NodeList<Element> result);
/**
* This method removes the element's parent. The matched elements replaces
@@ -2164,9 +2162,9 @@ public interface LazyGQuery<T> extends LazyBase<T>{
String[] vals();
/**
* Return true if the first element is visible.
*/
- boolean visible();
+ boolean isVisible();
/**
* Return the first non null attached widget from the matched elements or null
@@ -2164,9 +2162,9 @@ public interface LazyGQuery<T> extends LazyBase<T>{
String[] vals();
/**
- * Return true if the first element is visible.
+ * Return true if the first element is visible.isVisible
*/